@@ -175,30 +175,30 @@ class IveoDevice(Device):
         if command.executed:
             _LOGGER.info("Channel " + str(channel) + "successfully taught" )
 
-    def manualIveoCommand(self, idMask, command):
-        command = IveoCommandManual(idMask, command)
+    def manualIveoCommand(self, command):
+        command = IveoCommandManual(self.mask, command)
         command.execute(self.gateway)
         return command
 
-    def automaticIveoCommand(self, idMask, command):
-        command = IveoCommandAutomatic(idMask, command)
+    def automaticIveoCommand(self, command):
+        command = IveoCommandAutomatic(self.mask, command)
         command.execute(self.gateway)
         return command
 
 
-    def stop(self, idMask):
-        self.automaticIveoCommand(idMask, CommandTypeIveo.STOP)
+    def stop(self):
+        self.automaticIveoCommand(self.mask, CommandTypeIveo.STOP)
 
-    def moveDown(self, idMask):
-        self.automaticIveoCommand(idMask, CommandTypeIveo.DRIVEDOWN)
+    def moveDown(self):
+        self.automaticIveoCommand(self.mask, CommandTypeIveo.DRIVEDOWN)
     
-    def moveUpIveo(self, idMask):
-        self.automaticIveoCommand(idMask, CommandTypeIveo.DRIVEUP)
+    def moveUpIveo(self):
+        self.automaticIveoCommand(self.mask, CommandTypeIveo.DRIVEUP)
     
-    def moveIntermediatePosition1(self, idMask):
-        self.manualIveoCommand(idMask, CommandTypeIveo.POSITION_1)
+    def moveIntermediatePosition1(self):
+        self.manualIveoCommand(self.mask, CommandTypeIveo.POSITION_1)
 
-    def moveIntermediatePosition2(self, idMask):
-        self.manualIveoCommand(idMask, CommandTypeIveo.POSITION_2)
+    def moveIntermediatePosition2(self):
+        self.manualIveoCommand(self.mask, CommandTypeIveo.POSITION_2)
     
     
\ No newline at end of file
